@@ -36,23 +36,24 @@ static vvl::DescriptorPool::TypeCountMap GetMaxTypeCounts(const VkDescriptorPool
     return counts;
 }
 
-vvl::DescriptorPool::DescriptorPool(ValidationStateTracker *dev, const VkDescriptorPool pool,
-                                             const VkDescriptorPoolCreateInfo *pCreateInfo)
-    : StateObject(pool, kVulkanObjectTypeDescriptorPool),
+vvl::DescriptorPool::DescriptorPool(ValidationStateTracker &dev, const VkDescriptorPool handle,
+                                    const VkDescriptorPoolCreateInfo *pCreateInfo)
+    : StateObject(handle, kVulkanObjectTypeDescriptorPool),
+      safe_create_info(pCreateInfo),
+      create_info(*safe_create_info.ptr()),
       maxSets(pCreateInfo->maxSets),
-      createInfo(pCreateInfo),
       maxDescriptorTypeCount(GetMaxTypeCounts(pCreateInfo)),
       available_sets_(pCreateInfo->maxSets),
       available_counts_(maxDescriptorTypeCount),
       dev_data_(dev) {}
 
 void vvl::DescriptorPool::Allocate(const VkDescriptorSetAllocateInfo *alloc_info, const VkDescriptorSet *descriptor_sets,
-                                     const vvl::AllocateDescriptorSetsData *ds_data) {
+                                   const vvl::AllocateDescriptorSetsData &ds_data) {
     auto guard = WriteLock();
     // Account for sets and individual descriptors allocated from pool
     available_sets_ -= alloc_info->descriptorSetCount;
-    for (auto it = ds_data->required_descriptors_by_type.begin(); it != ds_data->required_descriptors_by_type.end(); ++it) {
-        available_counts_[it->first] -= ds_data->required_descriptors_by_type.at(it->first);
+    for (auto it = ds_data.required_descriptors_by_type.begin(); it != ds_data.required_descriptors_by_type.end(); ++it) {
+        available_counts_[it->first] -= ds_data.required_descriptors_by_type.at(it->first);
     }
 
     const auto *variable_count_info = vku::FindStructInPNextChain<VkDescriptorSetVariableDescriptorCountAllocateInfo>(alloc_info->pNext);
@@ -63,10 +64,10 @@ void vvl::DescriptorPool::Allocate(const VkDescriptorSetAllocateInfo *alloc_info
     for (uint32_t i = 0; i < alloc_info->descriptorSetCount; i++) {
         uint32_t variable_count = variable_count_valid ? variable_count_info->pDescriptorCounts[i] : 0;
 
-        auto new_ds = dev_data_->CreateDescriptorSet(descriptor_sets[i], this, ds_data->layout_nodes[i], variable_count);
+        auto new_ds = dev_data_.CreateDescriptorSet(descriptor_sets[i], this, ds_data.layout_nodes[i], variable_count);
 
         sets_.emplace(descriptor_sets[i], new_ds.get());
-        dev_data_->Add(std::move(new_ds));
+        dev_data_.Add(std::move(new_ds));
     }
 }
 
@@ -79,7 +80,7 @@ void vvl::DescriptorPool::Free(uint32_t count, const VkDescriptorSet *descriptor
     for (uint32_t i = 0; i < count; ++i) {
         if (descriptor_sets[i] != VK_NULL_HANDLE) {
             auto iter = sets_.find(descriptor_sets[i]);
-            assert(iter != sets_.end());
+            ASSERT_AND_CONTINUE(iter != sets_.end());
             auto *set_state = iter->second;
             const auto &layout = set_state->Layout();
             uint32_t type_index = 0, descriptor_count = 0;
@@ -88,7 +89,7 @@ void vvl::DescriptorPool::Free(uint32_t count, const VkDescriptorSet *descriptor
                 descriptor_count = layout.GetDescriptorCountFromIndex(j);
                 available_counts_[type_index] += descriptor_count;
             }
-            dev_data_->Destroy<vvl::DescriptorSet>(iter->first);
+            dev_data_.Destroy<vvl::DescriptorSet>(iter->first);
             sets_.erase(iter);
         }
     }
@@ -98,7 +99,7 @@ void vvl::DescriptorPool::Reset() {
     auto guard = WriteLock();
     // For every set off of this pool, clear it, remove from setMap, and free vvl::DescriptorSet
     for (auto entry : sets_) {
-        dev_data_->Destroy<vvl::DescriptorSet>(entry.first);
+        dev_data_.Destroy<vvl::DescriptorSet>(entry.first);
     }
     sets_.clear();
     // Reset available count for each type and available sets for this pool
@@ -183,6 +184,99 @@ DescriptorSetLayoutId GetCanonicalId(const VkDescriptorSetLayoutCreateInfo *p_cr
     return descriptor_set_layout_dict.LookUp(DescriptorSetLayoutDef(p_create_info));
 }
 
+bool operator==(const DescriptorSetLayoutDef &lhs, const DescriptorSetLayoutDef &rhs) {
+    // trivial types
+    if ((lhs.GetCreateFlags() != rhs.GetCreateFlags()) || (lhs.GetBindingFlags() != rhs.GetBindingFlags())) {
+        return false;
+    }
+    // vectors of enums
+    if (lhs.GetMutableTypes() != rhs.GetMutableTypes()) {
+        return false;
+    }
+    // vectors of vku::safe_VkDescriptorSetLayoutBinding structures
+    const auto &lhs_bindings = lhs.GetBindings();
+    const auto &rhs_bindings = rhs.GetBindings();
+    if (lhs_bindings.size() != rhs_bindings.size()) {
+        return false;
+    }
+    for (size_t i = 0; i < lhs_bindings.size(); i++) {
+        const auto &l = lhs_bindings[i];
+        const auto &r = rhs_bindings[i];
+        if (l.descriptorType != r.descriptorType || l.descriptorCount != r.descriptorCount || l.stageFlags != r.stageFlags) {
+            return false;
+        }
+        for (uint32_t s = 0; s < l.descriptorCount; s++) {
+            if (l.pImmutableSamplers[s] != r.pImmutableSamplers[s]) {
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
+std::string DescriptorSetLayoutDef::DescribeDifference(uint32_t index, const DescriptorSetLayoutDef &other) const {
+    std::ostringstream ss;
+    ss << "Set " << index << " ";
+    auto lhs_binding_flags = GetBindingFlags();
+    auto rhs_binding_flags = other.GetBindingFlags();
+    const auto &lhs_bindings = GetBindings();
+    const auto &rhs_bindings = other.GetBindings();
+
+    if (GetCreateFlags() != other.GetCreateFlags()) {
+        ss << "VkDescriptorSetLayoutCreateFlags " << string_VkDescriptorSetLayoutCreateFlags(GetCreateFlags()) << " doesn't match "
+           << string_VkDescriptorSetLayoutCreateFlags(other.GetCreateFlags());
+    } else if (lhs_binding_flags.size() != rhs_binding_flags.size()) {
+        ss << "VkDescriptorSetLayoutBindingFlagsCreateInfo::bindingCount " << lhs_binding_flags.size() << " doesn't match "
+           << rhs_binding_flags.size();
+    } else if (lhs_binding_flags != rhs_binding_flags) {
+        ss << "VkDescriptorSetLayoutBindingFlagsCreateInfo::pBindingFlags (";
+        for (auto flag : lhs_binding_flags) {
+            ss << string_VkDescriptorBindingFlags(flag) << " ";
+        }
+        ss << ") doesn't match (";
+        for (auto flag : rhs_binding_flags) {
+            ss << string_VkDescriptorBindingFlags(flag) << " ";
+        }
+        ss << ")";
+    } else if (GetMutableTypes() != other.GetMutableTypes()) {
+        // TODO - this is a 2d array, need a smarter way to print out details
+        ss << "Mutable types doesn't match";
+    } else if (lhs_bindings.size() != rhs_bindings.size()) {
+        ss << "binding count " << lhs_bindings.size() << " doesn't match " << rhs_bindings.size();
+    } else {
+        for (size_t i = 0; i < lhs_bindings.size(); i++) {
+            const auto &l = lhs_bindings[i];
+            const auto &r = rhs_bindings[i];
+            if (l.descriptorType != r.descriptorType) {
+                ss << "binding " << i << " descriptorType " << string_VkDescriptorType(l.descriptorType) << " doesn't match "
+                   << string_VkDescriptorType(r.descriptorType);
+                break;
+            } else if (l.descriptorCount != r.descriptorCount) {
+                ss << "binding " << i << " descriptorCount " << l.descriptorCount << " doesn't match " << r.descriptorCount;
+                break;
+            } else if (l.stageFlags != r.stageFlags) {
+                ss << "binding " << i << " stageFlags " << string_VkShaderStageFlags(l.stageFlags) << " doesn't match "
+                   << string_VkShaderStageFlags(r.stageFlags);
+                break;
+            } else if (l.pImmutableSamplers != r.pImmutableSamplers) {
+                ss << "binding " << i << " pImmutableSamplers " << l.pImmutableSamplers << " doesn't match "
+                   << r.pImmutableSamplers;
+                break;
+            } else if (l.pImmutableSamplers) {
+                for (uint32_t s = 0; s < l.descriptorCount; s++) {
+                    if (l.pImmutableSamplers[s] != r.pImmutableSamplers[s]) {
+                        ss << "binding " << i << " pImmutableSamplers[" << s << "] " << l.pImmutableSamplers[s] << " doesn't match "
+                           << r.pImmutableSamplers[s];
+                        break;
+                    }
+                }
+            }
+        }
+    }
+    ss << "\n";
+    return ss.str();
+}
+
 // Construct DescriptorSetLayout instance from given create info
 // Proactively reserve and resize as possible, as the reallocation was visible in profiling
 vvl::DescriptorSetLayoutDef::DescriptorSetLayoutDef(const VkDescriptorSetLayoutCreateInfo *p_create_info)
@@ -314,7 +408,6 @@ const vvl::IndexRange &vvl::DescriptorSetLayoutDef::GetGlobalIndexRangeFromBindi
 // Move to next valid binding having a non-zero binding count
 uint32_t vvl::DescriptorSetLayoutDef::GetNextValidBinding(const uint32_t binding) const {
     auto it = non_empty_bindings_.upper_bound(binding);
-    assert(it != non_empty_bindings_.cend());
     if (it != non_empty_bindings_.cend()) return *it;
     return GetMaxBinding() + 1;
 }
@@ -371,16 +464,16 @@ bool vvl::DescriptorSetLayout::IsCompatible(DescriptorSetLayout const *rh_ds_lay
 
 // The DescriptorSetLayout stores the per handle data for a descriptor set layout, and references the common defintion for the
 // handle invariant portion
-vvl::DescriptorSetLayout::DescriptorSetLayout(const VkDescriptorSetLayoutCreateInfo *p_create_info,
-                                                          const VkDescriptorSetLayout layout)
-    : StateObject(layout, kVulkanObjectTypeDescriptorSetLayout), layout_id_(GetCanonicalId(p_create_info)) {}
+vvl::DescriptorSetLayout::DescriptorSetLayout(const VkDescriptorSetLayoutCreateInfo *pCreateInfo,
+                                              const VkDescriptorSetLayout handle)
+    : StateObject(handle, kVulkanObjectTypeDescriptorSetLayout), layout_id_(GetCanonicalId(pCreateInfo)) {}
 
 void vvl::AllocateDescriptorSetsData::Init(uint32_t count) { layout_nodes.resize(count); }
 
-vvl::DescriptorSet::DescriptorSet(const VkDescriptorSet set, vvl::DescriptorPool *pool_state,
-                                              const std::shared_ptr<DescriptorSetLayout const> &layout, uint32_t variable_count,
-                                              vvl::DescriptorSet::StateTracker *state_data)
-    : StateObject(set, kVulkanObjectTypeDescriptorSet),
+vvl::DescriptorSet::DescriptorSet(const VkDescriptorSet handle, vvl::DescriptorPool *pool_state,
+                                  const std::shared_ptr<DescriptorSetLayout const> &layout, uint32_t variable_count,
+                                  vvl::DescriptorSet::StateTracker *state_data)
+    : StateObject(handle, kVulkanObjectTypeDescriptorSet),
       some_update_(false),
       pool_state_(pool_state),
       layout_(layout),
@@ -394,7 +487,8 @@ vvl::DescriptorSet::DescriptorSet(const VkDescriptorSet set, vvl::DescriptorPool
     auto free_binding = bindings_store_.data();
     for (uint32_t i = 0; i < binding_count; ++i) {
         auto create_info = layout_->GetDescriptorSetLayoutBindingPtrFromIndex(i);
-        assert(create_info);
+        ASSERT_AND_CONTINUE(create_info);
+
         uint32_t descriptor_count = create_info->descriptorCount;
         auto flags = layout_->GetDescriptorBindingFlagsFromIndex(i);
         if (flags & VK_DESCRIPTOR_BINDING_VARIABLE_DESCRIPTOR_COUNT_BIT) {
@@ -468,7 +562,7 @@ vvl::DescriptorSet::DescriptorSet(const VkDescriptorSet set, vvl::DescriptorPool
                 break;
             }
             default:
-                assert(0);  // Bad descriptor type specified
+                assert(false);  // Bad descriptor type specified
                 break;
         }
     }
@@ -488,6 +582,21 @@ void vvl::DescriptorSet::NotifyInvalidate(const NodeList &invalid_nodes, bool un
     }
 }
 
+uint32_t vvl::DescriptorSet::GetDynamicOffsetIndexFromBinding(uint32_t dynamic_binding) const {
+    const uint32_t index = layout_->GetIndexFromBinding(dynamic_binding);
+    if (index == bindings_.size()) {  // binding not found
+        return vvl::kU32Max;
+    }
+    assert(IsDynamicDescriptor(bindings_[index]->type));
+    uint32_t dynamic_offset_index = 0;
+    for (uint32_t i = 0; i < index; i++) {
+        if (IsDynamicDescriptor(bindings_[i]->type)) {
+            dynamic_offset_index += bindings_[i]->count;
+        }
+    }
+    return dynamic_offset_index;
+}
+
 void vvl::DescriptorSet::Destroy() {
     for (auto &binding : bindings_) {
         binding->RemoveParent(this);
@@ -504,7 +613,7 @@ void vvl::DescriptorSet::PerformPushDescriptorsUpdate(uint32_t write_count, cons
     push_descriptor_set_writes.clear();
     push_descriptor_set_writes.reserve(static_cast<std::size_t>(write_count));
     for (uint32_t i = 0; i < write_count; i++) {
-        push_descriptor_set_writes.push_back(safe_VkWriteDescriptorSet(&write_descs[i]));
+        push_descriptor_set_writes.push_back(vku::safe_VkWriteDescriptorSet(&write_descs[i]));
     }
 }
 
@@ -513,7 +622,7 @@ void vvl::DescriptorSet::PerformWriteUpdate(const VkWriteDescriptorSet &update)
     // Perform update on a per-binding basis as consecutive updates roll over to next binding
     auto descriptors_remaining = update.descriptorCount;
     auto iter = FindDescriptor(update.dstBinding, update.dstArrayElement);
-    assert(!iter.AtEnd());
+    ASSERT_AND_RETURN(!iter.AtEnd());
     auto &orig_binding = iter.CurrentBinding();
 
     // Verify next consecutive binding matches type, stage flags & immutable sampler use and if AtEnd
@@ -581,7 +690,8 @@ void vvl::DescriptorSet::UpdateDrawState(ValidationStateTracker *device_data, vv
     // resources
     for (const auto &binding_req_pair : binding_req_map) {
         auto *binding = GetBinding(binding_req_pair.first);
-        assert(binding);
+        ASSERT_AND_CONTINUE(binding);
+
         // core validation doesn't handle descriptor indexing, that is only done by GPU-AV
         if (SkipBinding(*binding, binding_req_pair.second.variable->is_dynamic_accessed)) {
             continue;
@@ -981,7 +1091,7 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const Validat
             range_ = buffer_info.range;
             const auto buffer_state = dev_data.GetConstCastShared<vvl::Buffer>(update.pBufferInfo->buffer);
             if (buffer_state) {
-                buffer_size = buffer_state->createInfo.size;
+                buffer_size = buffer_state->create_info.size;
             }
             ReplaceStatePtr(set_state, buffer_state_, buffer_state, is_bindless);
             break;
@@ -989,7 +1099,7 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const Validat
         case DescriptorClass::TexelBuffer: {
             const auto buffer_view = dev_data.GetConstCastShared<vvl::BufferView>(update.pTexelBufferView[index]);
             if (buffer_view) {
-                buffer_size = buffer_view->buffer_state->createInfo.size;
+                buffer_size = buffer_view->buffer_state->create_info.size;
             }
             ReplaceStatePtr(set_state, buffer_view_state_, buffer_view, is_bindless);
             break;
@@ -1118,7 +1228,7 @@ void vvl::MutableDescriptor::SetDescriptorType(VkDescriptorType src_type, const
             buffer_size_ = vvl::kU32Max;
         } else {
             auto buffer_state = static_cast<const vvl::BufferDescriptor *>(src)->GetBufferState();
-            buffer_size_ = static_cast<uint32_t>(buffer_state->createInfo.size);
+            buffer_size_ = static_cast<uint32_t>(buffer_state->create_info.size);
         }
     } else if (src->GetClass() == vvl::DescriptorClass::TexelBuffer) {
         auto buffer_view = static_cast<const vvl::TexelDescriptor *>(src)->GetBufferView();
@@ -1126,7 +1236,7 @@ void vvl::MutableDescriptor::SetDescriptorType(VkDescriptorType src_type, const
             buffer_size_ = vvl::kU32Max;
         } else {
             auto buffer_view_state = static_cast<const vvl::TexelDescriptor *>(src)->GetBufferViewState();
-            buffer_size_ = static_cast<uint32_t>(buffer_view_state->buffer_state->createInfo.size);
+            buffer_size_ = static_cast<uint32_t>(buffer_view_state->buffer_state->create_info.size);
         }
     } else if (src->GetClass() == vvl::DescriptorClass::Mutable) {
         auto descriptor = static_cast<const vvl::MutableDescriptor *>(src);
