@@ -24,7 +24,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetViewportWithCount(VkComman
                                                                         const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (viewportCount != 1) {
             skip |= LogError("VUID-vkCmdSetViewportWithCount-viewportCount-03395", commandBuffer,
                              error_obj.location.dot(Field::viewportCount),
@@ -55,7 +55,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetScissorWithCount(VkCommand
                                                                        const VkRect2D *pScissors,
                                                                        const ErrorObject &error_obj) const {
     bool skip = false;
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (scissorCount != 1) {
             skip |= LogError("VUID-vkCmdSetScissorWithCount-scissorCount-03398", commandBuffer,
                              error_obj.location.dot(Field::scissorCount),
@@ -121,8 +121,6 @@ bool StatelessValidation::manual_PreCallValidateCmdSetVertexInputEXT(
     const VkVertexInputBindingDescription2EXT *pVertexBindingDescriptions, uint32_t vertexAttributeDescriptionCount,
     const VkVertexInputAttributeDescription2EXT *pVertexAttributeDescriptions, const ErrorObject &error_obj) const {
     bool skip = false;
-    const auto *vertex_attribute_divisor_features =
-        vku::FindStructInPNextChain<VkPhysicalDeviceVertexAttributeDivisorFeaturesEXT>(device_createinfo_pnext);
 
     if (vertexBindingDescriptionCount > device_limits.maxVertexInputBindings) {
         skip |= LogError("VUID-vkCmdSetVertexInputEXT-vertexBindingDescriptionCount-04791", commandBuffer,
@@ -196,8 +194,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetVertexInputEXT(
                              pVertexBindingDescriptions[binding].stride, device_limits.maxVertexInputBindingStride);
         }
 
-        if (pVertexBindingDescriptions[binding].divisor == 0 &&
-            (!vertex_attribute_divisor_features || !vertex_attribute_divisor_features->vertexAttributeInstanceRateZeroDivisor)) {
+        if (pVertexBindingDescriptions[binding].divisor == 0 && (!enabled_features.vertexAttributeInstanceRateZeroDivisor)) {
             skip |=
                 LogError("VUID-VkVertexInputBindingDescription2EXT-divisor-04798", commandBuffer, binding_loc.dot(Field::divisor),
                          "is zero but "
@@ -205,7 +202,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetVertexInputEXT(
         }
 
         if (pVertexBindingDescriptions[binding].divisor > 1) {
-            if (!vertex_attribute_divisor_features || !vertex_attribute_divisor_features->vertexAttributeInstanceRateDivisor) {
+            if (!enabled_features.vertexAttributeInstanceRateDivisor) {
                 skip |= LogError("VUID-VkVertexInputBindingDescription2EXT-divisor-04799", commandBuffer,
                                  binding_loc.dot(Field::divisor),
                                  "is %" PRIu32
@@ -260,8 +257,8 @@ bool StatelessValidation::manual_PreCallValidateCmdSetVertexInputEXT(
         if ((properties.bufferFeatures & VK_FORMAT_FEATURE_VERTEX_BUFFER_BIT) == 0) {
             skip |=
                 LogError("VUID-VkVertexInputAttributeDescription2EXT-format-04805", commandBuffer, attribute_loc.dot(Field::format),
-                         "(%s) is not a "
-                         "VK_FORMAT_FEATURE_VERTEX_BUFFER_BIT supported format. (supported bufferFeatures: %s)",
+                         "(%s) doesn't support VK_FORMAT_FEATURE_VERTEX_BUFFER_BIT.\n"
+                         "(supported bufferFeatures: %s)",
                          string_VkFormat(pVertexAttributeDescriptions[attribute].format),
                          string_VkFormatFeatureFlags2(properties.bufferFeatures).c_str());
         }
@@ -344,7 +341,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetExclusiveScissorNV(VkComma
                                                                          const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (firstExclusiveScissor != 0) {
             skip |= LogError("VUID-vkCmdSetExclusiveScissorNV-firstExclusiveScissor-02035", commandBuffer,
                              error_obj.location.dot(Field::firstExclusiveScissor),
@@ -420,7 +417,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetViewportShadingRatePalette
     const VkShadingRatePaletteNV *pShadingRatePalettes, const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (firstViewport != 0) {
             skip |= LogError("VUID-vkCmdSetViewportShadingRatePaletteNV-firstViewport-02068", commandBuffer,
                              error_obj.location.dot(Field::firstViewport),
@@ -458,7 +455,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetCoarseSampleOrderNV(VkComm
     }
 
     for (uint32_t order_i = 0; order_i < customSampleOrderCount; ++order_i) {
-        skip |= ValidateCoarseSampleOrderCustomNV(&pCustomSampleOrders[order_i],
+        skip |= ValidateCoarseSampleOrderCustomNV(pCustomSampleOrders[order_i],
                                                   error_obj.location.dot(Field::pCustomSampleOrders, order_i));
     }
 
@@ -470,7 +467,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetViewport(VkCommandBuffer c
                                                                const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (firstViewport != 0) {
             skip |=
                 LogError("VUID-vkCmdSetViewport-firstViewport-01224", commandBuffer, error_obj.location.dot(Field::firstViewport),
@@ -506,7 +503,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetScissor(VkCommandBuffer co
                                                               const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.multiViewport) {
+    if (!enabled_features.multiViewport) {
         if (firstScissor != 0) {
             skip |= LogError("VUID-vkCmdSetScissor-firstScissor-00593", commandBuffer, error_obj.location.dot(Field::firstScissor),
                              "is %" PRIu32 " but the multiViewport feature was not enabled.", firstScissor);
@@ -563,7 +560,7 @@ bool StatelessValidation::manual_PreCallValidateCmdSetLineWidth(VkCommandBuffer
                                                                 const ErrorObject &error_obj) const {
     bool skip = false;
 
-    if (!physical_device_features.wideLines && (lineWidth != 1.0f)) {
+    if (!enabled_features.wideLines && (lineWidth != 1.0f)) {
         skip |= LogError("VUID-vkCmdSetLineWidth-lineWidth-00788", commandBuffer, error_obj.location.dot(Field::lineWidth),
                          "is %f (not 1.0), but wideLines was not enabled.", lineWidth);
     }
