@@ -159,6 +159,31 @@ bool StatelessValidation::ValidateRequiredPointer(const Location &loc, const voi
     return skip;
 }
 
+bool StatelessValidation::ValidateAllocationCallbacks(const VkAllocationCallbacks &callback, const Location &loc) const {
+    bool skip = false;
+    skip |= ValidateRequiredPointer(loc.dot(Field::pfnAllocation), reinterpret_cast<const void *>(callback.pfnAllocation),
+                                    "VUID-VkAllocationCallbacks-pfnAllocation-00632");
+
+    skip |= ValidateRequiredPointer(loc.dot(Field::pfnReallocation), reinterpret_cast<const void *>(callback.pfnReallocation),
+                                    "VUID-VkAllocationCallbacks-pfnReallocation-00633");
+
+    skip |= ValidateRequiredPointer(loc.dot(Field::pfnFree), reinterpret_cast<const void *>(callback.pfnFree),
+                                    "VUID-VkAllocationCallbacks-pfnFree-00634");
+
+    if (callback.pfnInternalAllocation) {
+        skip |=
+            ValidateRequiredPointer(loc.dot(Field::pfnInternalAllocation), reinterpret_cast<const void *>(callback.pfnInternalFree),
+                                    "VUID-VkAllocationCallbacks-pfnInternalAllocation-00635");
+    }
+
+    if (callback.pfnInternalFree) {
+        skip |=
+            ValidateRequiredPointer(loc.dot(Field::pfnInternalFree), reinterpret_cast<const void *>(callback.pfnInternalAllocation),
+                                    "VUID-VkAllocationCallbacks-pfnInternalAllocation-00635");
+    }
+    return skip;
+}
+
 /**
  * Validate string array count and content.
  *
@@ -180,7 +205,7 @@ bool StatelessValidation::ValidateStringArray(const Location &count_loc, const L
                                               const char *count_required_vuid, const char *array_required_vuid) const {
     bool skip = false;
 
-    if ((count == 0) || (array == nullptr)) {
+    if ((array == nullptr) || (count == 0)) {
         skip |= ValidateArray(count_loc, array_loc, count, &array, countRequired, arrayRequired, count_required_vuid,
                               array_required_vuid);
     } else {
@@ -214,8 +239,6 @@ bool StatelessValidation::ValidateStructPnext(const Location &loc, const void *n
                                               const char *stype_vuid, VkPhysicalDevice caller_physical_device,
                                               const bool is_const_param) const {
     bool skip = false;
-    const Location pNext_loc = loc.dot(Field::pNext);
-    const char *api_name = loc.StringFunc();
 
     if (next != nullptr) {
         vvl::unordered_set<const void *> cycle_check;
@@ -226,7 +249,8 @@ bool StatelessValidation::ValidateStructPnext(const Location &loc, const void *n
             "you are using a struct from a private extension or an extension that was added to a later version of the Vulkan "
             "header, in which case the use of %s is undefined and may not work correctly with validation enabled";
 
-        if ((allowed_type_count == 0) && (custom_stype_info.size() == 0)) {
+        const Location pNext_loc = loc.dot(Field::pNext);
+        if ((allowed_type_count == 0) && (custom_stype_info.empty())) {
             std::string message = "must be NULL. ";
             message += disclaimer;
             skip |= LogError(pnext_vuid, device, pNext_loc, message.c_str(), header_version, pNext_loc.Fields().c_str());
@@ -236,10 +260,8 @@ bool StatelessValidation::ValidateStructPnext(const Location &loc, const void *n
             const VkBaseOutStructure *current = reinterpret_cast<const VkBaseOutStructure *>(next);
 
             while (current != nullptr) {
-                if (((strncmp(api_name, "vkCreateInstance", strlen(api_name)) != 0) ||
-                     (current->sType != VK_STRUCTURE_TYPE_LOADER_INSTANCE_CREATE_INFO)) &&
-                    ((strncmp(api_name, "vkCreateDevice", strlen(api_name)) != 0) ||
-                     (current->sType != VK_STRUCTURE_TYPE_LOADER_DEVICE_CREATE_INFO))) {
+                if ((loc.function != Func::vkCreateInstance || (current->sType != VK_STRUCTURE_TYPE_LOADER_INSTANCE_CREATE_INFO)) &&
+                    (loc.function != Func::vkCreateDevice || (current->sType != VK_STRUCTURE_TYPE_LOADER_DEVICE_CREATE_INFO))) {
                     std::string type_name = string_VkStructureType(current->sType);
                     if (unique_stype_check.find(current->sType) != unique_stype_check.end() && !IsDuplicatePnext(current->sType)) {
                         // stype_vuid will only be null if there are no listed pNext and will hit disclaimer check
@@ -332,7 +354,7 @@ bool StatelessValidation::ValidateBool32Array(const Location &count_loc, const L
                                               const char *count_required_vuid, const char *array_required_vuid) const {
     bool skip = false;
 
-    if ((count == 0) || (array == nullptr)) {
+    if ((array == nullptr) || (count == 0)) {
         skip |= ValidateArray(count_loc, array_loc, count, &array, countRequired, arrayRequired, count_required_vuid,
                               array_required_vuid);
     } else {
@@ -377,10 +399,6 @@ bool StatelessValidation::ValidateFlagsImplementation(const Location &loc, vvl::
                                                       const char *flags_zero_vuid) const {
     bool skip = false;
 
-    if ((value & ~all_flags) != 0) {
-        skip |= LogError(vuid, device, loc, "contains flag bits that are not recognized members of %s.", String(flag_bitmask));
-    }
-
     const bool required = flag_type == kRequiredFlags || flag_type == kRequiredSingleBit;
     const char *zero_vuid = flag_type == kRequiredFlags ? flags_zero_vuid : vuid;
     if (required && value == 0) {
@@ -421,6 +439,12 @@ bool StatelessValidation::ValidateFlags(const Location &loc, vvl::FlagBitmask fl
                                         const FlagType flag_type, const char *vuid, const char *flags_zero_vuid) const {
     bool skip = false;
     skip |= ValidateFlagsImplementation<VkFlags>(loc, flag_bitmask, all_flags, value, flag_type, vuid, flags_zero_vuid);
+
+    if ((value & ~all_flags) != 0) {
+        skip |= LogError(vuid, device, loc, "contains flag bits (0x%" PRIx32 ") which are not recognized members of %s.", value,
+                         String(flag_bitmask));
+    }
+
     if (!skip && value != 0) {
         vvl::Extensions required = IsValidFlagValue(flag_bitmask, value, device_extensions);
         if (!required.empty() && device != VK_NULL_HANDLE) {
@@ -451,6 +475,12 @@ bool StatelessValidation::ValidateFlags(const Location &loc, vvl::FlagBitmask fl
                                         const FlagType flag_type, const char *vuid, const char *flags_zero_vuid) const {
     bool skip = false;
     skip |= ValidateFlagsImplementation<VkFlags64>(loc, flag_bitmask, all_flags, value, flag_type, vuid, flags_zero_vuid);
+
+    if ((value & ~all_flags) != 0) {
+        skip |= LogError(vuid, device, loc, "contains flag bits (0x%" PRIx64 ") which are not recognized members of %s.", value,
+                         String(flag_bitmask));
+    }
+
     if (!skip && value != 0) {
         vvl::Extensions required = IsValidFlag64Value(flag_bitmask, value, device_extensions);
         if (!required.empty() && device != VK_NULL_HANDLE) {
@@ -483,7 +513,7 @@ bool StatelessValidation::ValidateFlagsArray(const Location &count_loc, const Lo
                                              const char *count_required_vuid, const char *array_required_vuid) const {
     bool skip = false;
 
-    if ((count == 0) || (array == nullptr)) {
+    if ((array == nullptr) || (count == 0)) {
         // Flag arrays always need to have a valid array
         skip |= ValidateArray(count_loc, array_loc, count, &array, count_required, true, count_required_vuid, array_required_vuid);
     } else {
