@@ -113,16 +113,7 @@ CreatePipelineHelper::CreatePipelineHelper(VkLayerTest &test, void *pNext) : lay
     gp_ci_.renderPass = layer_test_.renderPass();
 }
 
-CreatePipelineHelper::~CreatePipelineHelper() {
-    if (pipeline_cache_ != VK_NULL_HANDLE) {
-        vk::DestroyPipelineCache(device_->handle(), pipeline_cache_, nullptr);
-        pipeline_cache_ = VK_NULL_HANDLE;
-    }
-    if (pipeline_ != VK_NULL_HANDLE) {
-        vk::DestroyPipeline(device_->handle(), pipeline_, nullptr);
-        pipeline_ = VK_NULL_HANDLE;
-    }
-}
+CreatePipelineHelper::~CreatePipelineHelper() { Destroy(); }
 
 void CreatePipelineHelper::InitShaderInfo() { ResetShaderInfo(kVertexMinimalGlsl, kFragmentMinimalGlsl); }
 
@@ -133,6 +124,17 @@ void CreatePipelineHelper::ResetShaderInfo(const char *vertex_shader_text, const
     shader_stages_ = {vs_->GetStageCreateInfo(), fs_->GetStageCreateInfo()};
 }
 
+void CreatePipelineHelper::Destroy() {
+    if (pipeline_cache_ != VK_NULL_HANDLE) {
+        vk::DestroyPipelineCache(device_->handle(), pipeline_cache_, nullptr);
+        pipeline_cache_ = VK_NULL_HANDLE;
+    }
+    if (pipeline_ != VK_NULL_HANDLE) {
+        vk::DestroyPipeline(device_->handle(), pipeline_, nullptr);
+        pipeline_ = VK_NULL_HANDLE;
+    }
+}
+
 // Designed for majority of cases that just need to simply add dynamic state
 void CreatePipelineHelper::AddDynamicState(VkDynamicState dynamic_state) {
     dynamic_states_.push_back(dynamic_state);
@@ -312,16 +314,7 @@ CreateComputePipelineHelper::CreateComputePipelineHelper(VkLayerTest &test, void
     cp_ci_.layout = VK_NULL_HANDLE;
 }
 
-CreateComputePipelineHelper::~CreateComputePipelineHelper() {
-    if (pipeline_cache_ != VK_NULL_HANDLE) {
-        vk::DestroyPipelineCache(device_->handle(), pipeline_cache_, nullptr);
-        pipeline_cache_ = VK_NULL_HANDLE;
-    }
-    if (pipeline_ != VK_NULL_HANDLE) {
-        vk::DestroyPipeline(device_->handle(), pipeline_, nullptr);
-        pipeline_ = VK_NULL_HANDLE;
-    }
-}
+CreateComputePipelineHelper::~CreateComputePipelineHelper() { Destroy(); }
 
 void CreateComputePipelineHelper::InitShaderInfo() {
     cs_ = std::make_unique<VkShaderObj>(&layer_test_, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT);
@@ -336,6 +329,17 @@ void CreateComputePipelineHelper::InitPipelineCache() {
     ASSERT_EQ(VK_SUCCESS, err);
 }
 
+void CreateComputePipelineHelper::Destroy() {
+    if (pipeline_cache_ != VK_NULL_HANDLE) {
+        vk::DestroyPipelineCache(device_->handle(), pipeline_cache_, nullptr);
+        pipeline_cache_ = VK_NULL_HANDLE;
+    }
+    if (pipeline_ != VK_NULL_HANDLE) {
+        vk::DestroyPipeline(device_->handle(), pipeline_, nullptr);
+        pipeline_ = VK_NULL_HANDLE;
+    }
+}
+
 void CreateComputePipelineHelper::LateBindPipelineInfo() {
     // By value or dynamically located items must be late bound
     if (cp_ci_.layout == VK_NULL_HANDLE) {
@@ -366,53 +370,61 @@ VkResult CreateComputePipelineHelper::CreateComputePipeline(bool do_late_bind) {
     return vk::CreateComputePipelines(device_->handle(), pipeline_cache_, 1, &cp_ci_, NULL, &pipeline_);
 }
 
-void SetDefaultDynamicStates(VkCommandBuffer cmdBuffer) {
-    uint32_t width = 32;
-    uint32_t height = 32;
-    VkViewport viewport = {0, 0, static_cast<float>(width), static_cast<float>(height), 0.0f, 1.0f};
-    VkRect2D scissor = {{0, 0}, {width, height}};
-    vk::CmdSetViewportWithCountEXT(cmdBuffer, 1u, &viewport);
-    vk::CmdSetScissorWithCountEXT(cmdBuffer, 1u, &scissor);
-    vk::CmdSetLineWidth(cmdBuffer, 1.0f);
-    vk::CmdSetDepthBias(cmdBuffer, 1.0f, 0.0f, 1.0f);
-    float blendConstants[4] = {1.0f, 1.0f, 1.0f, 1.0f};
-    vk::CmdSetBlendConstants(cmdBuffer, blendConstants);
-    vk::CmdSetDepthBounds(cmdBuffer, 0.0f, 1.0f);
-    vk::CmdSetStencilCompareMask(cmdBuffer, VK_STENCIL_FACE_FRONT_AND_BACK, 0xFFFFFFFF);
-    vk::CmdSetStencilWriteMask(cmdBuffer, VK_STENCIL_FACE_FRONT_AND_BACK, 0xFFFFFFFF);
-    vk::CmdSetStencilReference(cmdBuffer, VK_STENCIL_FACE_FRONT_AND_BACK, 0xFFFFFFFF);
-    vk::CmdSetCullModeEXT(cmdBuffer, VK_CULL_MODE_NONE);
-    vk::CmdSetDepthBoundsTestEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetDepthCompareOpEXT(cmdBuffer, VK_COMPARE_OP_NEVER);
-    vk::CmdSetDepthTestEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetDepthWriteEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetFrontFaceEXT(cmdBuffer, VK_FRONT_FACE_CLOCKWISE);
-    vk::CmdSetPrimitiveTopologyEXT(cmdBuffer, VK_PRIMITIVE_TOPOLOGY_TRIANGLE_STRIP);
-    vk::CmdSetStencilOpEXT(cmdBuffer, VK_STENCIL_FACE_FRONT_AND_BACK, VK_STENCIL_OP_KEEP, VK_STENCIL_OP_KEEP, VK_STENCIL_OP_KEEP,
-                           VK_COMPARE_OP_NEVER);
-    vk::CmdSetStencilTestEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetDepthBiasEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetPrimitiveRestartEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetRasterizerDiscardEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetVertexInputEXT(cmdBuffer, 0u, nullptr, 0u, nullptr);
-    vk::CmdSetLogicOpEXT(cmdBuffer, VK_LOGIC_OP_COPY);
-    vk::CmdSetPatchControlPointsEXT(cmdBuffer, 4u);
-    vk::CmdSetTessellationDomainOriginEXT(cmdBuffer, VK_TESSELLATION_DOMAIN_ORIGIN_UPPER_LEFT);
-    vk::CmdSetDepthClampEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetPolygonModeEXT(cmdBuffer, VK_POLYGON_MODE_FILL);
-    vk::CmdSetRasterizationSamplesEXT(cmdBuffer, VK_SAMPLE_COUNT_1_BIT);
-    VkSampleMask sampleMask = 0xFFFFFFFF;
-    vk::CmdSetSampleMaskEXT(cmdBuffer, VK_SAMPLE_COUNT_1_BIT, &sampleMask);
-    vk::CmdSetAlphaToCoverageEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetAlphaToOneEnableEXT(cmdBuffer, VK_FALSE);
-    vk::CmdSetLogicOpEnableEXT(cmdBuffer, VK_FALSE);
-    VkBool32 colorBlendEnable = VK_FALSE;
-    vk::CmdSetColorBlendEnableEXT(cmdBuffer, 0u, 1u, &colorBlendEnable);
-    VkColorBlendEquationEXT colorBlendEquation = {
-        VK_BLEND_FACTOR_ONE, VK_BLEND_FACTOR_ONE, VK_BLEND_OP_ADD, VK_BLEND_FACTOR_ONE, VK_BLEND_FACTOR_ONE, VK_BLEND_OP_ADD,
-    };
-    vk::CmdSetColorBlendEquationEXT(cmdBuffer, 0u, 1u, &colorBlendEquation);
-    VkColorComponentFlags colorWriteMask =
-        VK_COLOR_COMPONENT_R_BIT | VK_COLOR_COMPONENT_G_BIT | VK_COLOR_COMPONENT_B_BIT | VK_COLOR_COMPONENT_A_BIT;
-    vk::CmdSetColorWriteMaskEXT(cmdBuffer, 0u, 1u, &colorWriteMask);
+namespace vkt {
+
+GraphicsPipelineLibraryStage::GraphicsPipelineLibraryStage(vvl::span<const uint32_t> spv, VkShaderStageFlagBits stage) : spv(spv) {
+    shader_ci = vku::InitStructHelper();
+    shader_ci.codeSize = spv.size() * sizeof(uint32_t);
+    shader_ci.pCode = spv.data();
+
+    stage_ci = vku::InitStructHelper(&shader_ci);
+    stage_ci.stage = stage;
+    stage_ci.module = VK_NULL_HANDLE;
+    stage_ci.pName = "main";
 }
+
+SimpleGPL::SimpleGPL(VkLayerTest &test, VkPipelineLayout layout, const char *vertex_shader, const char *fragment_shader)
+    : vertex_input_lib_(test), pre_raster_lib_(test), frag_shader_lib_(test), frag_out_lib_(test) {
+    auto device = test.DeviceObj();
+
+    vertex_input_lib_.InitVertexInputLibInfo();
+    vertex_input_lib_.CreateGraphicsPipeline(false);
+
+    // For GPU-AV tests this shrinks things so only a single fragment is executed
+    VkViewport viewport = {0, 0, 1, 1, 0, 1};
+    VkRect2D scissor = {{0, 0}, {1, 1}};
+
+    const auto vs_spv = test.GLSLToSPV(VK_SHADER_STAGE_VERTEX_BIT, vertex_shader ? vertex_shader : kVertexMinimalGlsl);
+    vkt::GraphicsPipelineLibraryStage vs_stage(vs_spv, VK_SHADER_STAGE_VERTEX_BIT);
+    pre_raster_lib_.InitPreRasterLibInfo(&vs_stage.stage_ci);
+    pre_raster_lib_.vp_state_ci_.pViewports = &viewport;
+    pre_raster_lib_.vp_state_ci_.pScissors = &scissor;
+    pre_raster_lib_.gp_ci_.layout = layout;
+    pre_raster_lib_.CreateGraphicsPipeline();
+
+    const auto fs_spv = test.GLSLToSPV(VK_SHADER_STAGE_FRAGMENT_BIT, fragment_shader ? fragment_shader : kFragmentMinimalGlsl);
+    vkt::GraphicsPipelineLibraryStage fs_stage(fs_spv, VK_SHADER_STAGE_FRAGMENT_BIT);
+    frag_shader_lib_.InitFragmentLibInfo(&fs_stage.stage_ci);
+    frag_shader_lib_.gp_ci_.layout = layout;
+    frag_shader_lib_.CreateGraphicsPipeline(false);
+
+    frag_out_lib_.InitFragmentOutputLibInfo();
+    frag_out_lib_.CreateGraphicsPipeline(false);
+
+    VkPipeline libraries[4] = {
+        vertex_input_lib_.Handle(),
+        pre_raster_lib_.Handle(),
+        frag_shader_lib_.Handle(),
+        frag_out_lib_.Handle(),
+    };
+
+    VkPipelineLibraryCreateInfoKHR link_info = vku::InitStructHelper();
+    link_info.libraryCount = size(libraries);
+    link_info.pLibraries = libraries;
+
+    VkGraphicsPipelineCreateInfo exe_pipe_ci = vku::InitStructHelper(&link_info);
+    exe_pipe_ci.layout = layout;
+    pipe_.init(*device, exe_pipe_ci);
+}
+
+}  // namespace vkt
