@@ -17,6 +17,8 @@
 #include <sys/mman.h>
 #endif
 
+class PositiveMemory : public VkLayerTest {};
+
 TEST_F(PositiveMemory, MapMemory2) {
     TEST_DESCRIPTION("Validate vkMapMemory2 and vkUnmapMemory2");
 
@@ -131,6 +133,14 @@ TEST_F(PositiveMemory, MapMemoryPlaced) {
     res = vk::UnmapMemory2KHR(device(), &unmap_info);
     ASSERT_EQ(VK_SUCCESS, res);
 
+    /* Test mapping with the whole size but not VK_WHOLE_SIZE */
+    map_info.size = allocation_size;
+    res = vk::MapMemory2KHR(device(), &map_info, &pData);
+    ASSERT_EQ(VK_SUCCESS, res);
+
+    res = vk::UnmapMemory2KHR(device(), &unmap_info);
+    ASSERT_EQ(VK_SUCCESS, res);
+
     map_info.flags = 0;
     vk::MapMemory2KHR(device(), &map_info, &pData);
 
@@ -205,7 +215,8 @@ TEST_F(PositiveMemory, GetMemoryRequirements2) {
 
     // Submit and verify no validation errors
     m_commandBuffer->end();
-    m_commandBuffer->QueueCommandBuffer();
+    m_default_queue->Submit(*m_commandBuffer);
+    m_default_queue->Wait();
 }
 
 TEST_F(PositiveMemory, BindMemory2) {
@@ -263,7 +274,8 @@ TEST_F(PositiveMemory, BindMemory2) {
 
     // Submit and verify no validation errors
     m_commandBuffer->end();
-    m_commandBuffer->QueueCommandBuffer();
+    m_default_queue->Submit(*m_commandBuffer);
+    m_default_queue->Wait();
 }
 
 TEST_F(PositiveMemory, NonCoherentMapping) {
@@ -476,18 +488,8 @@ TEST_F(PositiveMemory, DeviceImageMemoryRequirements) {
 
     RETURN_IF_SKIP(Init());
 
-    VkImageCreateInfo image_create_info = vku::InitStructHelper();
-    image_create_info.imageType = VK_IMAGE_TYPE_2D;
-    image_create_info.format = VK_FORMAT_B8G8R8A8_UNORM;
-    image_create_info.extent.width = 32;
-    image_create_info.extent.height = 32;
-    image_create_info.extent.depth = 1;
-    image_create_info.mipLevels = 1;
-    image_create_info.arrayLayers = 1;
-    image_create_info.samples = VK_SAMPLE_COUNT_1_BIT;
-    image_create_info.tiling = VK_IMAGE_TILING_OPTIMAL;
-    image_create_info.usage = VK_IMAGE_USAGE_SAMPLED_BIT;
-    image_create_info.flags = 0;
+    VkImageCreateInfo image_create_info =
+        vkt::Image::ImageCreateInfo2D(32, 32, 1, 1, VK_FORMAT_B8G8R8A8_UNORM, VK_IMAGE_USAGE_SAMPLED_BIT);
     vkt::Image image(*m_device, image_create_info, vkt::no_mem);
 
     VkDeviceImageMemoryRequirements info = vku::InitStructHelper();
@@ -506,3 +508,63 @@ TEST_F(PositiveMemory, DeviceImageMemoryRequirements) {
     VkResult err = vk::BindImageMemory(device(), image, mem, 0);
     ASSERT_EQ(VK_SUCCESS, err);
 }
+
+#ifdef VK_USE_PLATFORM_WIN32_KHR
+TEST_F(PositiveMemory, BindMemoryDX11Handle) {
+    TEST_DESCRIPTION("Bind memory imported from DX11 resource. Allocation size should be ignored.");
+    AddRequiredExtensions(VK_KHR_EXTERNAL_MEMORY_WIN32_EXTENSION_NAME);
+    RETURN_IF_SKIP(Init());
+    // Mock ICD allows to use fake DX11 handles instead of using DX11 API directly.
+    if (!IsPlatformMockICD()) {
+        GTEST_SKIP() << "This test only runs on the mock ICD";
+    }
+
+    VkExternalMemoryImageCreateInfo external_info = vku::InitStructHelper();
+    external_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D11_TEXTURE_BIT;
+    auto image_ci = vkt::Image::ImageCreateInfo2D(32, 32, 1, 1, VK_FORMAT_B8G8R8A8_UNORM, VK_IMAGE_USAGE_SAMPLED_BIT);
+    image_ci.pNext = &external_info;
+    vkt::Image image(*m_device, image_ci, vkt::no_mem);
+
+    VkMemoryRequirements mem_reqs{};
+    vk::GetImageMemoryRequirements(device(), image.handle(), &mem_reqs);
+
+    VkImportMemoryWin32HandleInfoKHR memory_import = vku::InitStructHelper();
+    memory_import.handleType = VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D11_TEXTURE_BIT;
+    memory_import.handle = (HANDLE)0x12345678;  // Use arbitrary non-zero value as DX11 resource handle
+
+    VkMemoryAllocateInfo alloc_info = vku::InitStructHelper(&memory_import);  // Set zero allocation size
+    m_device->phy().set_memory_type(mem_reqs.memoryTypeBits, &alloc_info, 0);
+    vkt::DeviceMemory memory(*m_device, alloc_info);
+    // This should not trigger VUs that take into accout allocation size (e.g. 01049/01046)
+    vk::BindImageMemory(device(), image, memory, 0);
+}
+
+TEST_F(PositiveMemory, BindMemoryDX12Handle) {
+    TEST_DESCRIPTION("Bind memory imported from DX12 resource. Allocation size should be ignored.");
+    AddRequiredExtensions(VK_KHR_EXTERNAL_MEMORY_WIN32_EXTENSION_NAME);
+    RETURN_IF_SKIP(Init());
+    // Mock ICD allows to use fake DX12 handles instead of using DX12 API directly.
+    if (!IsPlatformMockICD()) {
+        GTEST_SKIP() << "This test only runs on the mock ICD";
+    }
+
+    VkExternalMemoryImageCreateInfo external_info = vku::InitStructHelper();
+    external_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D12_RESOURCE_BIT;
+    auto image_ci = vkt::Image::ImageCreateInfo2D(32, 32, 1, 1, VK_FORMAT_B8G8R8A8_UNORM, VK_IMAGE_USAGE_SAMPLED_BIT);
+    image_ci.pNext = &external_info;
+    vkt::Image image(*m_device, image_ci, vkt::no_mem);
+
+    VkMemoryRequirements mem_reqs{};
+    vk::GetImageMemoryRequirements(device(), image.handle(), &mem_reqs);
+
+    VkImportMemoryWin32HandleInfoKHR memory_import = vku::InitStructHelper();
+    memory_import.handleType = VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D12_RESOURCE_BIT;
+    memory_import.handle = (HANDLE)0x12345678;  // Use arbitrary non-zero value as DX12 resource handle
+
+    VkMemoryAllocateInfo alloc_info = vku::InitStructHelper(&memory_import);  // Set zero allocation size
+    m_device->phy().set_memory_type(mem_reqs.memoryTypeBits, &alloc_info, 0);
+    vkt::DeviceMemory memory(*m_device, alloc_info);
+    // This should not trigger VUs that take into accout allocation size (e.g. 01049/01046)
+    vk::BindImageMemory(device(), image, memory, 0);
+}
+#endif  // VK_USE_PLATFORM_WIN32_KHR
